@@ -189,9 +189,13 @@ class PhS3(PhAWS):
             :param path_prefix: S3 文件路径
         """
         file_paths = []
-        res = self.s3_client.list_objects(Bucket=bucket_name, Prefix=path_prefix)
-        for item in res['Contents']:
-            file_paths.append(item['Key'])
+        res = self.s3_client.list_objects(
+            Bucket=bucket_name,
+            Prefix=path_prefix
+        )
+        if 'Contents' in res:
+            for item in res['Contents']:
+                file_paths.append(item['Key'])
         return file_paths
 
     def copy_file(self, source_bucket, source_file_path, target_bucket, target_file_path):
